.. _examples:

########
Examples
########

Basic usage
-----------
*examples/basic_usage.py*:

.. literalinclude:: ../examples/basic_usage.py
   :language: python

Character variants
------------------
*examples/variants.py*:

.. literalinclude:: ../examples/variants.py
   :language: python

*examples/variant_ts_difficulties.py*:

.. literalinclude:: ../examples/variant_ts_difficulties.py
   :language: python
